@@ -187,7 +187,7 @@ def func_metadata(
             the model.
         structured_output: Controls whether the tool's output is structured or unstructured
             - If None, auto-detects based on the function's return type annotation
-            - If True, unconditionally creates a structured tool (return type annotation permitting)
+            - If True, creates a structured tool (return type annotation permitting)
             - If False, unconditionally creates an unstructured tool
 
         If structured, creates a Pydantic model for the function's result based on its annotation.
